@@ -85,65 +85,65 @@
         <translation>Kaldır</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="135"/>
-        <location filename="../appearancepage.cpp" line="209"/>
-        <location filename="../appearancepage.cpp" line="248"/>
+        <location filename="../appearancepage.cpp" line="137"/>
+        <location filename="../appearancepage.cpp" line="211"/>
+        <location filename="../appearancepage.cpp" line="250"/>
         <source>Enter Color Scheme Name</source>
         <translation>Renk Şeması Adını Girin</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="135"/>
-        <location filename="../appearancepage.cpp" line="209"/>
-        <location filename="../appearancepage.cpp" line="248"/>
+        <location filename="../appearancepage.cpp" line="137"/>
+        <location filename="../appearancepage.cpp" line="211"/>
+        <location filename="../appearancepage.cpp" line="250"/>
         <source>File name:</source>
         <translation>Dosya adı:</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="144"/>
-        <location filename="../appearancepage.cpp" line="220"/>
-        <location filename="../appearancepage.cpp" line="228"/>
-        <location filename="../appearancepage.cpp" line="258"/>
+        <location filename="../appearancepage.cpp" line="146"/>
+        <location filename="../appearancepage.cpp" line="222"/>
+        <location filename="../appearancepage.cpp" line="230"/>
+        <location filename="../appearancepage.cpp" line="260"/>
         <source>Error</source>
         <translation>Hata</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="144"/>
-        <location filename="../appearancepage.cpp" line="220"/>
-        <location filename="../appearancepage.cpp" line="258"/>
+        <location filename="../appearancepage.cpp" line="146"/>
+        <location filename="../appearancepage.cpp" line="222"/>
+        <location filename="../appearancepage.cpp" line="260"/>
         <source>The color scheme &quot;%1&quot; already exists</source>
         <translation>&quot;%1&quot; renk şeması zaten var</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="162"/>
-        <location filename="../appearancepage.cpp" line="185"/>
-        <location filename="../appearancepage.cpp" line="243"/>
+        <location filename="../appearancepage.cpp" line="164"/>
+        <location filename="../appearancepage.cpp" line="187"/>
+        <location filename="../appearancepage.cpp" line="245"/>
         <source>Warning</source>
         <translation>Uyarı</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="162"/>
-        <location filename="../appearancepage.cpp" line="185"/>
-        <location filename="../appearancepage.cpp" line="243"/>
+        <location filename="../appearancepage.cpp" line="164"/>
+        <location filename="../appearancepage.cpp" line="187"/>
+        <location filename="../appearancepage.cpp" line="245"/>
         <source>The color scheme &quot;%1&quot; is read only</source>
         <translation>&quot;%1&quot; renk şeması salt okunur</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="190"/>
+        <location filename="../appearancepage.cpp" line="192"/>
         <source>Confirm Remove</source>
         <translation>Kaldırmayı Onayla</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="191"/>
+        <location filename="../appearancepage.cpp" line="193"/>
         <source>Are you sure you want to remove color scheme &quot;%1&quot;?</source>
         <translation>&quot;%1&quot; renk şemasını kaldırmak istediğinizden emin misiniz?</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="211"/>
+        <location filename="../appearancepage.cpp" line="213"/>
         <source>%1 (copy)</source>
         <translation>%1 (kopya)</translation>
     </message>
     <message>
-        <location filename="../appearancepage.cpp" line="228"/>
+        <location filename="../appearancepage.cpp" line="230"/>
         <source>Unable to copy file</source>
         <translation>Dosya kopyalanamıyor</translation>
     </message>
@@ -428,65 +428,70 @@
         <translation>Gizle</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="50"/>
+        <location filename="../mainwindow.cpp" line="51"/>
         <source>Appearance</source>
         <translation>Görünüm</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="51"/>
+        <location filename="../mainwindow.cpp" line="52"/>
         <source>Fonts</source>
         <translation>Yazı Tipleri</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="52"/>
+        <location filename="../mainwindow.cpp" line="53"/>
         <source>Icon Theme</source>
         <translation>Simge Teması</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="53"/>
+        <location filename="../mainwindow.cpp" line="54"/>
         <source>Interface</source>
         <translation>Arayüz</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="55"/>
+        <location filename="../mainwindow.cpp" line="56"/>
         <source>Style Sheets</source>
         <translation>Tarz Sayfaları</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="57"/>
+        <location filename="../mainwindow.cpp" line="58"/>
         <source>Troubleshooting</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="64"/>
+        <location filename="../mainwindow.cpp" line="65"/>
         <source>Version: %1</source>
         <translation>Sürüm: %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="109"/>
+        <location filename="../mainwindow.cpp" line="110"/>
         <source>Warning</source>
         <translation>Uyarı</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="118"/>
+        <location filename="../mainwindow.cpp" line="119"/>
         <source>Please remove the &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; environment variable (current value: &lt;b&gt;%1&lt;/b&gt;).</source>
         <translation>Lütfen &lt;b&gt;QT_STYLE_OVERRIDE&lt;/b&gt; ortam değişkenini kaldırın (geçerli değer: &lt;b&gt;%1&lt;/b&gt;).</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="124"/>
-        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required value: &lt;b&gt;qt6ct&lt;/b&gt;).</source>
-        <translation>&lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; ortam değişkeni ayarlanmadı (gereken değer: &lt;b&gt;qt6ct&lt;/b&gt;).</translation>
+        <location filename="../mainwindow.cpp" line="125"/>
+        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set (required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="128"/>
-        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required value: &lt;b&gt;qt6ct&lt;/b&gt;).</source>
-        <translation>&lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; ortam değişkeni doğru ayarlanmadı (geçerli değer: &lt;b&gt;%1&lt;/b&gt;, gereken değer: &lt;b&gt;qt6ct&lt;/b&gt;).</translation>
+        <location filename="../mainwindow.cpp" line="130"/>
+        <source>The &lt;b&gt;QT_QPA_PLATFORMTHEME&lt;/b&gt; environment variable is not set correctly (current value: &lt;b&gt;%1&lt;/b&gt;, required values: &lt;b&gt;qt6ct&lt;/b&gt; or &lt;b&gt;qt5ct&lt;/b&gt;).</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="135"/>
+        <location filename="../mainwindow.cpp" line="137"/>
         <source>Unable to find &lt;b&gt;libqt6ct-style.so&lt;/b&gt;</source>
         <translation>&lt;b&gt;libqt6ct-style.so&lt;/b&gt; bulunamadı</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.cpp" line="143"/>
+        <source>The &lt;b&gt;%1&lt;/b&gt; plugin is compiled against incompatible Qt version (%2).</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PaletteEditDialog</name>
@@ -801,7 +806,7 @@
     <message>
         <location filename="../troubleshootingpage.ui" line="40"/>
         <source>Remove</source>
-        <translation type="unfinished">Kaldır</translation>
+        <translation>Kaldır</translation>
     </message>
     <message>
         <location filename="../troubleshootingpage.ui" line="73"/>
